@@ -118,8 +118,31 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateAccount(self, request):
+        """此接口用于创建数据账号，返回的Oid为账号唯一标识。与数据库系统表pg_roles中记录的oid一致。
+
+        :param request: Request instance for CreateAccount.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.CreateAccountRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.CreateAccountResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAccount", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAccountResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateBaseBackup(self, request):
-        """本接口（CreateBaseBackup）用于创建实例的全量备份。
+        """本接口（CreateBaseBackup）用于创建实例的数据备份。
 
         :param request: Request instance for CreateBaseBackup.
         :type request: :class:`tencentcloud.postgres.v20170312.models.CreateBaseBackupRequest`
@@ -189,8 +212,8 @@ class PostgresClient(AbstractClient):
 
     def CreateInstances(self, request):
         """本接口 (CreateInstances) 用于创建一个或者多个PostgreSQL实例，通过此接口创建的实例无需进行初始化，可直接使用。
-        <li>实例创建成功后将自动开机启动，实例状态变为“运行中”。
-        <li>预付费实例的购买会预先扣除本次实例购买所需金额，按小时后付费实例购买会预先冻结本次实例购买一小时内所需金额，在调用本接口前请确保账户余额充足。
+        <li>实例创建成功后将自动开机启动，实例状态变为“运行中”。</li>
+        <li>预付费实例的购买会预先扣除本次实例购买所需金额，按小时后付费实例购买会预先冻结本次实例购买一小时内所需金额，在调用本接口前请确保账户余额充足。</li>
 
         :param request: Request instance for CreateInstances.
         :type request: :class:`tencentcloud.postgres.v20170312.models.CreateInstancesRequest`
@@ -327,8 +350,31 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteAccount(self, request):
+        """此接口用于删除数据库账号，需要同时输入Oid与UserName，避免误删。
+
+        :param request: Request instance for DeleteAccount.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.DeleteAccountRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.DeleteAccountResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteAccount", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteAccountResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteBaseBackup(self, request):
-        """本接口（DeleteBaseBackup）用于删除实例指定全量备份。
+        """本接口（DeleteBaseBackup）用于删除实例指定数据备份。
 
         :param request: Request instance for DeleteBaseBackup.
         :type request: :class:`tencentcloud.postgres.v20170312.models.DeleteBaseBackupRequest`
@@ -488,6 +534,29 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeAccountPrivileges(self, request):
+        """查询数据库账号对某数据库对象拥有的权限列表。
+
+        :param request: Request instance for DescribeAccountPrivileges.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.DescribeAccountPrivilegesRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.DescribeAccountPrivilegesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeAccountPrivileges", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeAccountPrivilegesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeAccounts(self, request):
         """本接口（DescribeAccounts）用于查询实例的数据库账号列表。
 
@@ -650,7 +719,7 @@ class PostgresClient(AbstractClient):
 
 
     def DescribeBaseBackups(self, request):
-        """本接口（DescribeBaseBackups）用于查询基础备份列表。
+        """本接口（DescribeBaseBackups）用于查询数据备份列表。
 
         :param request: Request instance for DescribeBaseBackups.
         :type request: :class:`tencentcloud.postgres.v20170312.models.DescribeBaseBackupsRequest`
@@ -950,6 +1019,29 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeDatabaseObjects(self, request):
+        """本接口用于查询数据库对象列表。例如查询test数据库下的模式列表。
+
+        :param request: Request instance for DescribeDatabaseObjects.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.DescribeDatabaseObjectsRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.DescribeDatabaseObjectsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeDatabaseObjects", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeDatabaseObjectsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeDatabases(self, request):
         """接口（DescribeDatabases）用来查询实例的数据库列表。
 
@@ -1456,8 +1548,54 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def LockAccount(self, request):
+        """此接口用于锁定数据库账号，锁定后账号当前连接会断开，并且无法建立新连接。
+
+        :param request: Request instance for LockAccount.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.LockAccountRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.LockAccountResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("LockAccount", params, headers=headers)
+            response = json.loads(body)
+            model = models.LockAccountResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyAccountPrivileges(self, request):
+        """修改某账号对某数据库对象的权限、修改账号类型。
+
+        :param request: Request instance for ModifyAccountPrivileges.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.ModifyAccountPrivilegesRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.ModifyAccountPrivilegesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyAccountPrivileges", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyAccountPrivilegesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyAccountRemark(self, request):
-        """本接口（ModifyAccountRemark）用于修改帐号备注。
+        """本接口（ModifyAccountRemark）用于修改账号备注。
 
         :param request: Request instance for ModifyAccountRemark.
         :type request: :class:`tencentcloud.postgres.v20170312.models.ModifyAccountRemarkRequest`
@@ -1526,7 +1664,7 @@ class PostgresClient(AbstractClient):
 
 
     def ModifyBaseBackupExpireTime(self, request):
-        """本接口（ModifyBaseBackupExpireTime）用于修改实例指定全量备份的过期时间。
+        """本接口（ModifyBaseBackupExpireTime）用于修改实例指定数据备份的过期时间。
 
         :param request: Request instance for ModifyBaseBackupExpireTime.
         :type request: :class:`tencentcloud.postgres.v20170312.models.ModifyBaseBackupExpireTimeRequest`
@@ -1987,6 +2125,29 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def RestoreDBInstanceObjects(self, request):
+        """根据备份集或恢复目标时间，在原实例上恢复数据库相关对象，例如数据库、表。
+
+        :param request: Request instance for RestoreDBInstanceObjects.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.RestoreDBInstanceObjectsRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.RestoreDBInstanceObjectsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RestoreDBInstanceObjects", params, headers=headers)
+            response = json.loads(body)
+            model = models.RestoreDBInstanceObjectsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def SetAutoRenewFlag(self, request):
         """本接口（SetAutoRenewFlag）用于设置自动续费。
 
@@ -2036,6 +2197,29 @@ class PostgresClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def UnlockAccount(self, request):
+        """解除数据库账号的锁定，解锁后账号可以登陆数据库。
+
+        :param request: Request instance for UnlockAccount.
+        :type request: :class:`tencentcloud.postgres.v20170312.models.UnlockAccountRequest`
+        :rtype: :class:`tencentcloud.postgres.v20170312.models.UnlockAccountResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UnlockAccount", params, headers=headers)
+            response = json.loads(body)
+            model = models.UnlockAccountResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def UpgradeDBInstance(self, request):
         """本接口（UpgradeDBInstance）用于升级实例配置。本接口已废弃，推荐使用接口[ModifyDBInstanceSpec](https://cloud.tencent.com/document/api/409/63689)替代。
 
